@@ -13,8 +13,8 @@
 
 /* these includes are needed for Qt support */
 #include <QApplication>
-#include <QLayout>
 #include <QPushButton>
+#include <QRandomGenerator>
 
 #ifdef DEBUG
 #include <QDebug>
@@ -191,12 +191,12 @@ void ExerciseCompare::update()
 void ExerciseCompare::createTask()
 {
     // generate the first ratio
-    m_firstRatio = Ratio(int ((double(qrand()) / RAND_MAX) * 10 + 1), int ((double(qrand()) / RAND_MAX) * 10 + 1));
+    m_firstRatio = Ratio(QRandomGenerator::global()->bounded(10) + 1, QRandomGenerator::global()->bounded(10) + 1);
 
     // now the second ratio, but make sure, the second ratio is different from
     // the first one
     do {
-        m_secondRatio = Ratio(int ((double(qrand()) / RAND_MAX) * 10 + 1), int ((double(qrand()) / RAND_MAX) * 10 + 1));
+        m_secondRatio = Ratio(QRandomGenerator::global()->bounded(10) + 1, QRandomGenerator::global()->bounded(10) + 1);
     } while (m_firstRatio == m_secondRatio);
 
     return;
